@@ -17,6 +17,7 @@
 
 """Automatically fix lintian issues."""
 
+from contextlib import ExitStack
 from datetime import datetime
 import errno
 import io
@@ -56,7 +57,7 @@ from breezy.workspace import reset_tree, check_clean_tree
 from debmutate.reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 133)
+__version__ = (0, 135)
 version_string = ".".join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ["certain", "confident", "likely", "possible", None]
 DEFAULT_MINIMUM_CERTAINTY = "certain"
@@ -202,7 +203,7 @@ class Fixer(object):
     fixer addresses.
     """
 
-    def __init__(self, name: str, lintian_tags: List[str] = None):
+    def __init__(self, name: str, lintian_tags: Optional[List[str]] = None):
         self.name = name
         self.lintian_tags = lintian_tags or []
 
@@ -508,6 +509,10 @@ class ScriptFixer(Fixer):
         return parse_script_fixer_output(description.decode("utf-8"))
 
 
+def open_binary(name):
+    return open(data_file_path(name), 'rb')
+
+
 def data_file_path(name, check=os.path.exists):
     # There's probably a more Pythonic way of doing this, but
     # I haven't bothered finding out what it is yet..
@@ -524,7 +529,9 @@ def data_file_path(name, check=os.path.exists):
         return path
 
     # Urgh.
-    for b in ['/usr/share/lintian-brush', '/usr/local/share/lintian-brush']:
+    for b in ['/usr/share/lintian-brush',
+              '/usr/local/share/lintian-brush',
+              os.path.join(sys.prefix, 'share/lintian-brush')]:
         path = os.path.join(b, name)
         if check(path):
             return path
@@ -562,7 +569,7 @@ def read_desc_file(
 
 
 def select_fixers(
-    fixers: List[Fixer], names: List[str],
+    fixers: List[Fixer], *, names: Optional[List[str]] = None,
     exclude: Optional[Iterable[str]] = None
 ) -> List[Fixer]:
     """Select fixers by name, from a list.
@@ -574,18 +581,23 @@ def select_fixers(
     Raises:
       KeyError: if one of the names did not exist
     """
-    names_set = set(names)
-    if exclude:
-        for name in exclude:
-            if name not in names_set:
-                raise KeyError(name)
-            names_set.remove(name)
-    available = set([f.name for f in fixers])
-    missing = names_set - available
-    if missing:
-        raise KeyError(missing.pop())
-    # Preserve order
-    return [f for f in fixers if f.name in names_set]
+    select_set = set(names) if names is not None else None
+    exclude_set = set(exclude) if exclude is not None else None
+    ret = []
+    for f in fixers:
+        if select_set is not None:
+            if f.name not in select_set:
+                continue
+            select_set.remove(f.name)
+        if exclude_set and f.name in exclude_set:
+            exclude_set.remove(f.name)
+            continue
+        ret.append(f)
+    if select_set:
+        raise KeyError(select_set.pop())
+    if exclude_set:
+        raise KeyError(exclude_set.pop())
+    return ret
 
 
 def available_lintian_fixers(
@@ -625,7 +637,8 @@ def increment_version(v: Version) -> None:
         )
     else:
         v.upstream_version = re.sub(
-            "\\d+$", lambda x: str(int(x.group()) + 1), v.upstream_version
+            "\\d+$", lambda x: str(int(x.group()) + 1),
+            v.upstream_version or ''
         )
 
 
@@ -1018,8 +1031,8 @@ class ManyResult(object):
 
 
 def get_dirty_tracker(
-    local_tree: WorkingTree, subpath: str = "", use_inotify: bool = None
-):
+        local_tree: WorkingTree, subpath: str = "",
+        use_inotify: Optional[bool] = None):
     """Create a dirty tracker object."""
     if use_inotify is True:
         from breezy.dirty_tracker import DirtyTracker
@@ -1110,9 +1123,6 @@ def run_lintian_fixers(  # noqa: C901
     basis_tree = local_tree.basis_tree()
     check_clean_tree(local_tree, basis_tree=basis_tree, subpath=subpath)
     fixers = list(fixers)
-    dirty_tracker = get_dirty_tracker(
-        local_tree, subpath=subpath, use_inotify=use_inotify
-    )
 
     # If we don't know whether to update the changelog, then find out *once*
     if update_changelog is None:
@@ -1128,7 +1138,16 @@ def run_lintian_fixers(  # noqa: C901
         changelog_behaviour = None
 
     ret = ManyResult()
-    with trange(len(fixers), leave=False, disable=None) as t:
+    with ExitStack() as es:
+        t = es.enter_context(trange(len(fixers), leave=False, disable=None))
+
+        dirty_tracker = get_dirty_tracker(
+            local_tree, subpath=subpath, use_inotify=use_inotify
+        )
+        # Only Breezy >= 3.3.1 has DirtyTracker as a context manager
+        if dirty_tracker and hasattr(dirty_tracker, '__enter__'):
+            es.enter_context(dirty_tracker)
+
         for i, fixer in enumerate(fixers):
             t.set_description("Running fixer %s" % fixer)
             t.update()
@@ -1156,10 +1175,9 @@ def run_lintian_fixers(  # noqa: C901
                 ret.formatting_unpreservable[fixer.name] = e.path
                 if verbose:
                     logging.info(
-                        "Fixer %r was unable to preserve formatting of %s.",
-                        fixer.name,
-                        e.path,
-                    )
+                        "Fixer %r was unable to preserve "
+                        "formatting of %s.", fixer.name,
+                        e.path)
             except FixerFailed as e:
                 ret.failed_fixers[fixer.name] = e
                 if verbose:
@@ -1184,7 +1202,8 @@ def run_lintian_fixers(  # noqa: C901
             except FailedPatchManipulation as e:
                 if verbose:
                     logging.info(
-                        "Unable to manipulate upstream patches: %s", e.args[2])
+                        "Unable to manipulate upstream patches: %s",
+                        e.args[2])
                 ret.failed_fixers[fixer.name] = e
             except NoChanges as e:
                 if verbose:
