@@ -57,12 +57,13 @@ from breezy.errors import (
 )
 from breezy.commit import NullCommitReporter, PointlessCommit
 from breezy.revision import NULL_REVISION
+from breezy.tree import Tree
 from breezy.workingtree import WorkingTree
 
 from breezy.transport import FileExists
 
 from ognibuild import DetailedFailure, UnidentifiedError
-from ognibuild.buildlog import InstallFixer, problem_to_upstream_requirement
+from ognibuild.buildlog import problem_to_upstream_requirement
 from ognibuild.buildsystem import (
     get_buildsystem, NoBuildToolsFound, BuildSystem)
 from ognibuild.debian.apt import AptManager
@@ -84,7 +85,7 @@ from ognibuild.session.schroot import SchrootSession
 from ognibuild.requirements import (
     Requirement,
     )
-from ognibuild.resolver.apt import AptResolver, AptRequirement
+from ognibuild.resolver.apt import AptRequirement
 from ognibuild.upstream import (
     find_upstream,
     find_apt_upstream,
@@ -133,6 +134,7 @@ from buildlog_consultant.common import (
 from debmutate.versions import (
     debianize_upstream_version,
 )
+from debmutate.vcs import unsplit_vcs_url
 
 from . import (
     available_lintian_fixers,
@@ -145,8 +147,12 @@ from .debhelper import (
     maximum_debhelper_compat_version,
     write_rules_template as write_debhelper_rules_template,
 )
-from .publish import update_offical_vcs, NoVcsLocation, VcsAlreadySpecified
+from .publish import (
+    update_offical_vcs,
+    NoVcsLocation,
+)
 from .standards_version import latest_standards_version
+from .upstream_deps import get_project_wide_deps
 
 
 Kickstarter = Callable[[WorkingTree, str], None]
@@ -780,45 +786,6 @@ class DebianizeResult(object):
     vcs_url: Optional[str] = None
 
 
-def get_project_wide_deps(
-        session, wt, subpath, buildsystem, buildsystem_subpath):
-    build_deps = []
-    test_deps = []
-
-    with session:
-        external_dir, internal_dir = session.setup_from_vcs(
-            wt, os.path.join(subpath, buildsystem_subpath))
-
-        from ognibuild.debian.udd import popcon_tie_breaker
-        from ognibuild.debian.build_deps import BuildDependencyTieBreaker
-        apt_resolver = AptResolver.from_session(
-            session, tie_breakers=[
-                BuildDependencyTieBreaker.from_session(session),
-                popcon_tie_breaker,
-                ])
-        build_fixers = [InstallFixer(apt_resolver)]
-        session.chdir(internal_dir)
-        try:
-            upstream_deps = list(buildsystem.get_declared_dependencies(
-                session, build_fixers))
-        except NotImplementedError:
-            logging.warning('Unable to obtain declared dependencies.')
-        else:
-            for kind, dep in upstream_deps:
-                apt_dep = apt_resolver.resolve(dep)
-                if apt_dep is None:
-                    logging.warning(
-                        'Unable to map upstream requirement %s (kind %s) '
-                        'to a Debian package', dep, kind)
-                    continue
-                logging.debug('Mapped %s (kind: %s) to %s', dep, kind, apt_dep)
-                if kind in ('core', 'build'):
-                    build_deps.append(apt_dep)
-                if kind in ('core', 'test', ):
-                    test_deps.append(apt_dep)
-    return (build_deps, test_deps)
-
-
 def import_build_deps(source, build_deps):
     for build_dep in build_deps:
         for rel in build_dep.relations:
@@ -965,6 +932,7 @@ def debianize(  # noqa: C901
 
     def import_metadata_from_path(p):
         metadata_items.extend(guess_upstream_info(p, trust_package=trust))
+        assert isinstance(metadata, dict)
         metadata.update(
             summarize_upstream_metadata(
                 metadata_items, p, net_access=net_access,
@@ -1183,10 +1151,8 @@ def debianize(  # noqa: C901
         )
 
         try:
-            result.vcs_url = update_offical_vcs(
-                wt, subpath=subpath, committer=committer)
-        except VcsAlreadySpecified:
-            pass
+            result.vcs_url = unsplit_vcs_url(*update_offical_vcs(
+                wt, subpath=subpath, committer=committer))
         except NoVcsLocation:
             logging.debug(
                 'No public VCS location specified and unable to guess it '
@@ -1215,6 +1181,8 @@ class SimpleTrustedAptRepo(object):
         return False
 
     def sources_lines(self):
+        if not self.httpd:
+            raise RuntimeError("httpd not yet started")
         if os.path.exists(os.path.join(self.directory, 'Packages.gz')):
             return [
                 "deb [trusted=yes] http://%s:%d/ ./" % (
@@ -1251,8 +1219,12 @@ class SimpleTrustedAptRepo(object):
         self.thread.start()
 
     def stop(self):
-        self.httpd.shutdown()
-        self.thread.join()
+        if self.httpd is not None:
+            self.httpd.shutdown()
+            self.httpd = None
+        if self.thread is not None:
+            self.thread.join()
+            self.thread = None
 
     def refresh(self):
         import gzip
@@ -1412,7 +1384,7 @@ def main(argv=None):  # noqa: C901
     import argparse
 
     import breezy
-    breezy.initialize()
+    breezy.initialize()  # type: ignore
     import breezy.git  # noqa: E402
     import breezy.bzr  # noqa: E402
 
@@ -1567,6 +1539,7 @@ def main(argv=None):  # noqa: C901
             'it should add the packaging: %s', e)
         return 1
 
+    create_dist: Optional[Callable[[Tree, str, str, str], str]]
     if args.dist_command:
         def create_dist(tree, package, version, target_dir):
             return run_dist_command(
@@ -1604,7 +1577,7 @@ def main(argv=None):  # noqa: C901
         use_packaging_branch(
             wt, args.debian_branch % {'vendor': get_vendor_name().lower()})
 
-    use_inotify = ((False if args.disable_inotify else None),)
+    use_inotify = ((False if args.disable_inotify else None))
     with wt.lock_write():
         try:
             debianize_result = debianize(
