@@ -19,6 +19,7 @@
 
 from debian.changelog import Version
 import os
+import re
 from typing import Optional, Iterator, Callable, List, Tuple
 
 from debmutate.lintian_overrides import (
@@ -28,7 +29,7 @@ from debmutate.lintian_overrides import (
 )
 
 
-from . import data_file_path
+from . import open_binary
 
 
 def overrides_paths() -> Iterator[str]:
@@ -216,7 +217,7 @@ def remove_unused(
 
 def load_renamed_tags():
     import json
-    with open(data_file_path('renamed-tags.json'), "rb") as f:
+    with open_binary('renamed-tags.json') as f:
         return json.load(f)
 
 
@@ -226,13 +227,20 @@ LINENO_MATCH = r"\d+|\*"
 
 # "$file (line $lineno)" => "[$file:$lineno]"
 PURE_FLN_SUB = (
-    r"^(?P<path>[^[].*) \(line (?P<lineno>" + LINENO_MATCH + r")\)$",
+    r"^(?P<path>[^[ ].+) \(line (?P<lineno>" + LINENO_MATCH + r")\)$",
     r"[\1:\2]")
 # "$file (line $lineno)" => "* [$file:$lineno]"
 PURE_FLN_WILDCARD_SUB = (
-    r"^(?P<path>.+) \(line (?P<lineno>" + LINENO_MATCH + r")\)$", r"* [\1:\2]")
+    r"^(?P<path>[^ ]+) \(line (?P<lineno>" + LINENO_MATCH + r")\)$",
+    r"* [\1:\2]")
+INTERTWINED_FLN_SUB = [
+    (r"^(?P<path>[^ ]+) (.+) \(line (" + LINENO_MATCH + r")\)",
+     r"\2 [\1:\3]"),
+    (r"^(?P<path>[^ ]+) (.+) \*", r"\2 [\1:*]"),
+    (r"^(?P<path>[^ ]+) \*", r"* [\1:*]"),
+]
 # "$file" => "[$file]"
-PURE_FN_SUB = (r"^(?P<path>[^[].*)", r"[\1]")
+PURE_FN_SUB = (r"^(?P<path>[^[ ]+)", r"[\1]")
 
 
 # When adding new expressions here, make sure the first argument doesn't match
@@ -248,9 +256,7 @@ INFO_FIXERS = {
             r"\1 [debian/source/options:\2]"),
     "global-files-wildcard-not-first-paragraph-in-dep5-copyright":
         PURE_FLN_SUB,
-    "missing-license-paragraph-in-dep5-copyright": (
-        r"([^ ]+) (.*) \(line (" + LINENO_MATCH + r")\)",
-        r"\2 [\1:\3]"),
+    "missing-license-paragraph-in-dep5-copyright": INTERTWINED_FLN_SUB,
     "unused-license-paragraph-in-dep5-copyright": (
         r"([^ ]+) (.*) \(line (" + LINENO_MATCH + r")\)",
         r"\2 [\1:\3]"),
@@ -276,37 +282,43 @@ INFO_FIXERS = {
     "uses-dpkg-database-directly": PURE_FN_SUB,
     "package-contains-documentation-outside-usr-share-doc": PURE_FN_SUB,
     "non-standard-dir-perm": (
-        r"^(?P<path>.+) ([0-9]+) \!= ([0-9]+)", r"\2 != \3 [\1]"),
+        r"^(?P<path>[^ ]+) ([0-9]+) \!= ([0-9]+)", r"\2 != \3 [\1]"),
     "non-standard-file-perm": (
-        r"^(?P<path>.+) ([0-9]+) \!= ([0-9]+)", r"\2 != \3 [\1]"),
+        r"^(?P<path>[^ ]+) ([0-9]+) \!= ([0-9]+)", r"\2 != \3 [\1]"),
     "executable-is-not-world-readable": (
-        r"^(?P<path>.+) ([0-9]+)", r"\1 [\2]"),
+        r"^(?P<path>[^ ]+) ([0-9]+)", r"\2 [\1]"),
     "library-not-linked-against-libc": PURE_FN_SUB,
     "setuid-binary": (
-        r"^(?P<path>.+) (?P<mode>[0-9]+) (.+/.+)", r"\2 \3 [\1]"),
+        r"^(?P<path>[^[ ]+) (?P<mode>[0-9]+) (.+/.+)", r"\2 \3 [\1]"),
     "elevated-privileges": (
-        r"^(?P<path>.+) (?P<mode>[0-9]+) (.+/.+)", r"\2 \3 [\1]"),
+        r"^(?P<path>[^[ ]+) (?P<mode>[0-9]+) (.+/.+)", r"\2 \3 [\1]"),
     "executable-in-usr-lib": PURE_FN_SUB,
     "executable-not-elf-or-script": PURE_FN_SUB,
     "image-file-in-usr-lib": PURE_FN_SUB,
     "extra-license-file": PURE_FN_SUB,
     "script-not-executable": PURE_FN_SUB,
     "shell-script-fails-syntax-check": PURE_FN_SUB,
-    "manpage-has-errors-from-man": (r"^(?P<path).+) (.*)", r"\2 [\1]"),
-    "groff-message": (r"^(?P<path).+) (.*)", r"\2 [\1]"),
-    "source-contains-prebuilt-javascript-object": PURE_FN_SUB,
+    "manpage-has-errors-from-man": (r"^(?P<path)[^[ ]+) ([^[]*)", r"\2 [\1]"),
+    "groff-message": (r"^(?P<path)[^ ]+) ([^[ ]+)", r"\2 [\1]"),
+    "source-contains-prebuilt-javascript-object": [
+        PURE_FN_SUB,
+        (r"^(?P<path>[^[ ].+) line length is .*", r"[\1]")],
     "source-contains-prebuilt-java-object": PURE_FN_SUB,
     "source-contains-prebuilt-windows-binary": PURE_FN_SUB,
     "source-contains-prebuilt-doxygen-documentation": PURE_FN_SUB,
     "source-contains-prebuilt-wasm-binary": PURE_FN_SUB,
     "source-contains-prebuilt-binary": PURE_FN_SUB,
-    "source-is-missing": PURE_FN_SUB,
-    "spelling-error-in-binary": (r"^(?P<path>.+) (.+) (.+)$", r"\2 \3 [\1]"),
-    "very-long-line-length-in-source-file":
+    "source-is-missing": [
+        (r"^(?P<path>[^[ ].+) line length is .*", r"[\1]"),
+        PURE_FN_SUB],
+    "spelling-error-in-binary":
+        (r"^(?P<path>[^[ ]+) (.+) ([^[]+)$", r"\2 \3 [\1]"),
+    "very-long-line-length-in-source-file": [
         (r"(.*) line ([0-9]+) is ([0-9]+) characters long \(>([0-9]+)\)",
          r"\3 > \4 [\1:\2]"),
-    "missing-license-text-in-dep5-copyright":
-        ("^(?P<path>.+) (.+)$", r"\2 [\1:*\]"),
+        (r"^(?P<path>[^ ]+) \*", r"* [\1:*]"),
+        (r"^(?P<path>[^ ]+) line \*$", r"* [\1:*]")],
+    "missing-license-text-in-dep5-copyright": INTERTWINED_FLN_SUB,
     "national-encoding": PURE_FN_SUB,
     "no-manual-page": PURE_FN_SUB,
     "package-contains-empty-directory": PURE_FN_SUB,
@@ -317,7 +329,7 @@ INFO_FIXERS = {
     "license-problem-non-free-img-lenna": PURE_FN_SUB,
     "file-without-copyright-information": ("^(.*)$", r"\1 [debian/copyright]"),
     "globbing-patterns-out-of-order":
-        ("^(?P<path>.+) (.+)$", r"\2 [\1:*]"),
+        ("^(?P<path>.+) ([^[]+)$", r"\2 [\1:*]"),
     "statically-linked-binary": PURE_FN_SUB,
     "spare-manual-page": PURE_FN_SUB,
     "shared-library-lacks-prerequisites": PURE_FN_SUB,
@@ -325,6 +337,11 @@ INFO_FIXERS = {
     "hardening-no-pie": PURE_FN_SUB,
     "obsolete-url-in-packaging": (
         r"^(?P<path>.+) (.+)$", r"\2 [\1]"),
+    "inconsistent-appstream-metadata-license": (
+        r'^(.+) \(([^ ]+) \!= ([^)]+)\)$',
+        r'\1 (\2 != \3) [debian/copyright]'),
+    "source-ships-excluded-file": (
+        r"^([^ ]+)$", r"\1 [debian/copyright:*]"),
 }
 
 
@@ -337,10 +354,15 @@ def fix_override_info(override):
     else:
         info = override.info
         if not isinstance(fixers, list):
-            fixers = [fixers]
+            fixers = [fixers]  # type: ignore
         for fixer in fixers:
             if isinstance(fixer, tuple):
-                info = re.sub(fixer[0], fixer[1], override.info)
+                info = re.sub(fixer[0], fixer[1], info)
+                # The regex should only apply once
+                if re.sub(fixer[0], fixer[1], info) != info:
+                    raise AssertionError(
+                        "invalid repeatable regex for %s: %s" % (
+                             override.tag, fixer[0]))
             elif callable(fixer):
                 info = fixer(info) or info
             else:
